@@ -3,15 +3,12 @@ import traceback
 import requests
 import time
 import pandas as pd
+import datetime
+import numpy as np
 pd.set_option('display.max_rows', 500)
 pd.set_option('display.max_columns', 500)
 pd.set_option('display.width', 1000)
-try:
-    from ngw_contract_backtest.ngw.constants import LOGFLAG
-    if LOGFLAG:
-        from ngw_contract_backtest.ngw.utils.log_util import print
-except:
-    LOGFLAG = False
+
 
 def exchange2num(exchange):
     if exchange is None:
